@@ -35,10 +35,12 @@ def get_item(response, source, block, parse=True):
     item["domain_url"] = block["domain_url"]
     item["domain_id"] = block["domain_id"]
     item["domain_name"] = block["domain_name"]
-    item["source_url"] = source["url"]
-    item["source_id"] = source["identification"]
-    item["source_name"] = source["name"]
-    item["upload_oss"] = source.get('upload_oss', False)
+    item["upload_oss"] = True
+    if source:
+        item["source_url"] = source["url"]
+        item["source_id"] = source["identification"]
+        item["source_name"] = source["name"]
+        item["upload_oss"] = source.get('upload_oss', False)
     item["url"] = response.url
     item["url_md5"] = hashlib.md5(response.url.encode("utf-8")).hexdigest()
     if parse:
@@ -83,7 +85,8 @@ def __get_content_images(response, path):
 
 
 def __get_content_videos(response, path):
-    movie_list = "{}/descendant::video/@src".format(path)
+    movie_path = "{}/descendant::video/@src".format(path)
+    movie_list = response.xpath(movie_path).extract()
     movie_last = get_video_list(response, movie_list)
     return movie_last
 
@@ -178,7 +181,14 @@ def get_date(date_str, date_strip_list):
     date = None
     for date_strip in date_strip_list:
         try:
-            date = datetime.datetime.strptime(date_str, date_strip)
+            if date_strip == "s":
+                s = int(date_str)
+                date = datetime.datetime.fromtimestamp(s)
+            elif date_strip == "ms":
+                ms = int(date_str) / 1000.0
+                date = datetime.datetime.fromtimestamp(ms)
+            else:
+                date = datetime.datetime.strptime(date_str, date_strip)
         except:
             pass
         if date:
